@@ -1,5 +1,5 @@
 <?php
-$lang['friendlyname'] = 'File Manager';
+$lang['friendlyname'] = 'File Manager ';
 $lang['permission'] = 'Uso del modulo File Manager';
 $lang['permissionadvanced'] = 'Uso avanzato del modulo File Manager';
 $lang['moddescription'] = 'Associazione di files e directory nella sezione upload di cmsms';
@@ -12,6 +12,7 @@ $lang['fileview'] = 'Visualizza file';
 $lang['switchtofileview'] = 'Passa alla visualizzazione file';
 $lang['settings'] = 'Impostazioni';
 $lang['savesettings'] = 'Salva Impostazioni';
+$lang['postletexists'] = 'Attenzione! Si prega di rimuovere completamente la cartella modules/FileManager/postlet poich&egrave; obsoleta e pericolosa.';
 $lang['filename'] = 'Nome file';
 $lang['fileinfo'] = 'Info file';
 $lang['fileowner'] = 'Possessore del file';
@@ -21,18 +22,18 @@ $lang['filedate'] = 'Data';
 $lang['actions'] = 'Azioni';
 $lang['delete'] = 'Elimina';
 $lang['notwritable'] = 'Non scrivibile';
-$lang['filetoobig'] = 'troppo grande. Upload cancellato.';
+$lang['afileistoobig'] = 'Un file &egrave; troppo grande. Upload cancellato.';
 $lang['unknown'] = 'Sconosciuto';
 $lang['fileoutsideuploads'] = 'Voi non avete il permesso di modificare file al di fuori della directory di uploads! (Questo richiede permessi di Advanced File Management)';
 $lang['writable'] = 'Scrivibile';
 $lang['writeprotected'] = 'Protetto da scrittura';
-$lang['bytes'] = 'bytes';
+$lang['bytes'] = 'bytes ';
 $lang['kb'] = 'KB';
 $lang['mb'] = 'MB';
 $lang['files'] = 'file';
-$lang['bytesin'] = 'bytes in';
-$lang['in'] = 'in';
-$lang['file'] = 'file';
+$lang['bytesin'] = 'bytes in ';
+$lang['in'] = 'in ';
+$lang['file'] = 'file ';
 $lang['fileno'] = 'File numero';
 $lang['subdirs'] = 'sottodirectory';
 $lang['subdir'] = 'sottodirectory';
@@ -60,6 +61,13 @@ $lang['movedto'] = 'mosso a';
 $lang['copiedto'] = 'copiato a';
 $lang['couldnotmove'] = 'non pu&ograve; essere mosso';
 $lang['couldnotcopy'] = 'non pu&ograve; essere copiato';
+$lang['filesdeletedsuccessfully'] = '%s file(s) sono stati cancellati con successo';
+$lang['filesdeletedfiled'] = '%s file(s) fallita la cancellazione';
+$lang['filesmovedsuccessfully'] = '%s file(s) sono stati mossi con successo';
+$lang['filesmovedfailed'] = '%s file(s) fallito lo spostamento';
+$lang['filescopiedsuccessfully'] = '%s file(s) sono stati copiati con successo';
+$lang['filescopiedfailed'] = '%s file(s) fallito da copiare';
+$lang['internalerror'] = 'Errore Interno (significa qualche operazione fallita, si prega di riportare l&#039;operazione effettuata)';
 $lang['rename'] = 'Rinomina';
 $lang['newname'] = 'Nuovo nome:';
 $lang['renamesuccess'] = 'File rinominato correttamente';
@@ -79,6 +87,8 @@ $lang['chmodselected'] = 'Cambia permessi sui file selezionati';
 $lang['chmodsuccess'] = 'File modificato con i nuovi permessi';
 $lang['chmodfailure'] = 'Cambio dei permessi del file fallito';
 $lang['chmodcancelled'] = 'Cambio dei permessi cancellato';
+$lang['newuploadfailed'] = '%s file(s) fallito l&#039;upload (o l&#039;eventuale decompressione)';
+$lang['newuploadsuccess'] = '%s file(s) uploaded con successo (e l&#039;eventuale decompressione se scelta)';
 $lang['dirchmodfailmulti'] = 'Il cambio dei permessi sulla directory &egrave; fallito, sebbene alcuni dei componenti potrebbero aver preso i nuovi permessi.';
 $lang['dirchmodsuccessmulti'] = 'Il cambio dei permessi sulla directory e i suoi componenti ha avuto successo';
 $lang['dirchmodsuccess'] = 'La directory ha preso correttamente i nuovi permessi';
@@ -87,7 +97,7 @@ $lang['dirnotemptyconfirm'] = 'La directory non &egrave; vuota. Volete veramente
 $lang['dirtreedeletecancelled'] = 'Eliminazione della directory annnullata';
 $lang['imsure'] = 'Sono sicuro';
 $lang['cancel'] = 'Annulla';
-$lang['ok'] = 'OK';
+$lang['ok'] = 'OK ';
 $lang['uploadnewfile'] = 'Carica nuovo/i file:';
 $lang['unpackafterupload'] = 'Cerca di decomprimere dopo il caricamento (solo file di tipo tgz e zip)?';
 $lang['uploadsuccess'] = 'Il file &egrave; stato caricato con successo';
@@ -96,11 +106,12 @@ $lang['unpacksuccess'] = 'Il file &egrave; stato decompresso con successo';
 $lang['unpackfail'] = 'Si &egrave; verificato un errore durante la decompressione del file:';
 $lang['packfileopenfail'] = 'Non posso aprire il file compresso per la decompressione (formato non supportato?)';
 $lang['packfilewritefail'] = 'Non posso aprire il file %s per la scrittura';
-$lang['containsillegalchars'] = 'Filename contiene uno o pi&ugrave; caratteri illegali (&#039;,&quot;,+,*,\,/,&amp;,$)';
+$lang['afilecontainsillegalchars'] = 'A file contiene uno o pi&ugrave; caratteri illegali (&#039;,&quot;,+,*,\,/,&amp;,$). Upload cancellato.';
 $lang['currentpath'] = 'Path corrente:';
 $lang['newdirname'] = 'Crea nuova directory:';
 $lang['newdirsuccess'] = 'La directory &egrave; stata creata con successo';
 $lang['newdirfail'] = 'Si &egrave; verificato un errore durante la creazione della directory';
+$lang['direxists'] = 'La directory &egrave; gi&agrave; presente';
 $lang['invalidnewdir'] = 'Il nome della nuova cartella non pu&ograve; contenere caratteri come /, \ e &#039;..&#039;';
 $lang['filedateformat'] = 'd/m/Y H:m:s';
 $lang['iconsize'] = 'Dimensione Icona';
@@ -115,7 +126,7 @@ $lang['uploadfilesto'] = 'Carica i files in:';
 $lang['uploadview'] = 'Carica files';
 $lang['uploadboxes'] = 'Numero di blocchi di caricamento';
 $lang['nothinguploaded'] = 'Non &egrave; stato caricato nulla';
-$lang['unsupportedarchive'] = 'Formato di archivio non supportato';
+$lang['newunsupportedarchive'] = '%s &egrave; un formato di archivio non supportato';
 $lang['uploadmethod'] = 'Metodo di caricamento';
 $lang['uploaderstandard'] = 'Metodo di input html standard (permette la decompressione)';
 $lang['enableadvanced'] = 'Abilita modalit&agrave; avanzata?';
@@ -128,9 +139,8 @@ $lang['help'] = '		<h3>Cosa fa?</h3>
 		<p>Fornisce funzionalit&agrave; di gestione dei file</p>
 		<h3>Come si usa?</h3>
 		<p>Selezionalo dal menu Contenuto nella sezione di amministrazione.</p>';
-$lang['qca'] = 'P0-341425854-1271258489279';
-$lang['utma'] = '156861353.1785716972.1271258827.1272464498.1272484592.7';
-$lang['utmz'] = '156861353.1272484592.7.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299072468.1';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272484592';
+$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
