@@ -34,6 +34,7 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
+if (!isset($gCms)) exit;
 
 define('MINIMUM_REPOSITORY_VERSION','1.3');
 
@@ -73,7 +74,7 @@ class ModuleManager extends CMSModule
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.3.3';
+    return '1.4.2';
   }
 
 
@@ -209,13 +210,13 @@ class ModuleManager extends CMSModule
   {
     $this->smarty->assign('title_error', $this->Lang('error'));
     $this->smarty->assign_by_ref('message', $message);
+	$this->smarty->assign('link_back',$this->CreateLink($id,'defaultadmin',$returnid, $this->Lang('back_to_module_manager')));	
 	  
     // Display the populated template
     echo $this->ProcessTemplate('error.tpl');
   }
 	
 
-
   /*---------------------------------------------------------
    GetDependencies()
    ---------------------------------------------------------*/
@@ -230,7 +231,7 @@ class ModuleManager extends CMSModule
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.6-beta1";
+    return "1.8-beta1";
   }
 
 
@@ -313,7 +314,16 @@ class ModuleManager extends CMSModule
 	{
 	  if ($this->CheckAccess($id, $params, $returnid,'Modify Modules'))
 	    {
-	      $this->_DoAdminInstallModule( $id, $params, $returnid );
+	      $this->_DoRecursiveInstall( $id, $params, $returnid );
+	    }
+	  break;
+	}
+
+      case 'doinstall':
+	{
+	  if ($this->CheckAccess($id, $params, $returnid,'Modify Modules'))
+	    {
+	      $this->_DoInstallLoop( $id, $params, $returnid );
 	    }
 	  break;
 	}
@@ -335,6 +345,10 @@ class ModuleManager extends CMSModule
 	  $this->_DisplayAdminSoapModuleAbout( $id, $params, $returnid );
 	}
 	break;
+	 case 'recurseinstall':
+		{
+		$this->_DoRecursiveInstall( $id, $params, $returnid);
+		}
 
       // fallback through to call the action.xxxx.php file
       default:
@@ -456,8 +470,13 @@ class ModuleManager extends CMSModule
     $curletter = 'A';
     if( isset( $params['curletter'] ) )
       {
-	$curletter = $params['curletter'];
-      }    
+	  $curletter = $params['curletter'];
+	  $_SESSION['mm_curletter'] = $curletter;
+      }
+    else if (isset($_SESSION['mm_curletter']))
+      {
+	  $curletter = $_SESSION['mm_curletter'];
+      }
 
     // get the modules available in the repository
     $repmodules = '';
@@ -730,6 +749,7 @@ class ModuleManager extends CMSModule
     $this->smarty->assign('modulename',$name);
     $this->smarty->assign('moduleversion',$version);
     $this->smarty->assign('xmlfile',$xmlfile);
+	$this->smarty->assign('link_back',$this->CreateLink($id,'defaultadmin',$returnid, $this->Lang('back_to_module_manager')));	
 
     $txt = '';
     if( is_array($depends[1]) )
@@ -819,6 +839,8 @@ class ModuleManager extends CMSModule
     $this->smarty->assign('moduleversion',$version);
     $this->smarty->assign('xmlfile',$xmlfile);
     $this->smarty->assign('content',$help[1]);
+	$this->smarty->assign('link_back',$this->CreateLink($id,'defaultadmin',$returnid, $this->Lang('back_to_module_manager')));	
+
     echo $this->ProcessTemplate('remotecontent.tpl');
   }
 
@@ -969,40 +991,46 @@ class ModuleManager extends CMSModule
 				  $depends[1] );
 	return;
       }
-    if( is_array($depends[1]) )
-      {
-	global $gCms;
-	// check dependencies against what is installed.
-	$tmp = array();
-	foreach( $depends[1] as $onedep )
-	  {
-	    if( isset($gCms->modules[$onedep['name']]) ) 
-	      {
-		$mod =& $gCms->modules[$onedep['name']]['object'];
-		if( is_object($mod) )
-		  {
-		    if( version_compare($mod->GetVersion(),$onedep['version']) >= 0 )
-		      {
-			continue;
-		      }
-		  }
-	      }
-	    $tmp[] = $onedep;
-	  }
-
-	if( count($tmp) )
-	  {
-	    $txt = $this->Lang('error_depends').'<br/>';
-	    $txt .= '<ul>';
-	    foreach( $tmp as $one )
-	      {
-		$txt  .= '<li>'.$one['name'].' => '.$one['version'].'<br/>';
-	      }
-            $txt .= '</ul>';
-	    $this->_DisplayErrorPage( $id, $params, $returnid, $txt );
-	    return;
-	  }
-      }
+    if (! $this->_DetermineUnfulfilledDependencies($depends[1]))
+		{
+		
+    	if( is_array($depends[1]) )
+			{
+			$tmp = array();
+			foreach( $depends[1] as $onedep )
+	  			{
+	    		if ($onedep['status'] != 's') 
+	      			{
+	    			$tmp[] = $onedep;
+	  				}
+				}
+				
+			if (count($tmp) )
+	  			{
+				$txt = $this->Lang('error_depends').'<br/>';
+				$txt .= '<ul>';
+				foreach ( $tmp as $one )
+	      			{
+					switch ($one['status'])
+					 	{
+						case 'i':
+							$txt .= '<li>'.$this->Lang('depend_install',array($one['name'],$one['version'])).'</li>';
+							break;
+						case 'u':
+							$txt .= '<li>'.$this->Lang('depend_upgrade',array($one['name'],$one['version'])).'</li>';
+							break;
+						case 'a':
+							$txt .= '<li>'.$this->Lang('depend_activate',$one['name']).'</li>';
+							break;
+						}
+	      			}
+            	$txt .= '</ul>';
+				$txt .= '<br />'.$this->CreateLink($id,'recurseinstall',$returnid, $this->Lang('install_with_deps'), array('filename'=>$params['filename'])).'<br /><br />';
+	    		$this->_DisplayErrorPage( $id, $params, $returnid, $txt );
+	    		return;
+	  			}
+      		}
+		}
 
     // get the xml file from soap
     $xml = '';
@@ -1064,7 +1092,7 @@ class ModuleManager extends CMSModule
 	    $msg = $cmsmodules[$name]['object']->InstallPostMessage();
 	    if( $msg != FALSE )
 	      {
-		echo $msg;
+		echo $msg."<br /><br />".$this->CreateLink($id,'defaultadmin',$returnid, $this->Lang('back_to_module_manager'));
 	      }
 	    else
 	      {
@@ -1080,13 +1108,437 @@ class ModuleManager extends CMSModule
   }
 
 
+  /* Given an array of module dependencies (as returned from _DoRecursiveInstall),
+	 this returns a boolean indicating whether they're all satisfied.
+	 It also modified the incoming array to add a status for each dependency, indicating
+	 what, if anything, needs to be done:
+		s - satisfied
+		a - needs to be activated
+		i - needs to be installed
+		u - needs to be upgraded
+  */
+  function _DetermineUnfulfilledDependencies(&$depends)
+  {
+	$satisfied = true;
+	if( is_array($depends) )
+		{
+		$installed = $this->_GetInstalledModules(true,true);
+		if (is_array($installed[1]))
+			{
+			// check dependencies against what is installed.
+			foreach( $depends as $depkey=>$onedep )
+				{
+				if (isset($installed[1][$onedep['name']]) ) 
+					{
+					$mod = $installed[1][$onedep['name']];
+					if ($mod['active'])
+						{
+						if (version_compare($mod['version'],$onedep['version']) >= 0 )
+							{
+							$depends[$depkey]['status'] = 's';
+							continue;
+							}
+						else
+							{
+							$depends[$depkey]['status'] = 'u';
+							}							
+						}
+					else
+						{
+						$depends[$depkey]['status'] = 'a';
+						}
+			  		}
+				if (! isset($depends[$depkey]['status']))
+					{
+					$depends[$depkey]['status'] = 'i';
+					}
+				$satisfied = false;
+				}
+	    	}
+		}
+	return $satisfied;
+	}
+
+
+	function _DoRecursiveInstall($id, &$params, $returnid)
+		{
+		$allmods = $this->_GetRepositoryModules('',false);
+		$deps = array(array('name'=>$params['name'],'version'=>$params['version'],'filename'=>$params['filename'],
+							'by'=>'','size'=>$params['size']));
+		if (! $allmods[0])
+			{
+		 	 $this->_DisplayErrorPage( $id, $params, $returnid, $allmods[1] );
+		 	 return;
+			}
+		$ret = $this->_AddDependenciesToList($params['filename'], $allmods, $deps);
+		if (!$ret[0])
+			{
+			$this->_DisplayErrorPage( $id, $params, $returnid, $ret[1]);
+			return;
+			}
+		// de-dupe list
+		$deps = $this->_DeDupeDependencies($deps);
+		
+		$this->_DetermineUnfulfilledDependencies($deps);
+		$tmp = array();
+		foreach( $deps as $onedep )
+		  	{
+		    if ($onedep['status'] != 's') 
+		      	{
+		    	$tmp[] = $onedep;
+		  		}
+			}
+		if (count($tmp) > 1)
+		  	{
+			$txt = '<p>'.$this->Lang('notice_depends', $this->_ModNameFromFile($allmods[1],$params['filename'])).'</p>';
+			$txt .= '<ul>';
+			foreach ( $tmp as $one )
+		      	{
+				if (isset($one['version']) && $one['filename'] != $params['filename'])
+					{
+					switch ($one['status'])
+						{
+						case 'i':
+							$txt .= '<li>'.$this->Lang('depend_install',array($one['name'],$one['version'])).'</li>';
+							break;
+						case 'u':
+							$txt .= '<li>'.$this->Lang('depend_upgrade',array($one['name'],$one['version'])).'</li>';
+							break;
+						case 'a':
+							$txt .= '<li>'.$this->Lang('depend_activate',$one['name']).'</li>';
+							break;
+						}
+			      	}
+				}
+	        $txt .= '</ul>';
+
+		    $this->smarty->assign('title_installation', $this->Lang('title_installation'));
+		    $this->smarty->assign('message', $txt);
+			$this->smarty->assign('link_back',$this->CreateLink($id,'defaultadmin',$returnid, $this->Lang('back_to_module_manager')));	
+		
+		    $this->smarty->assign('form_start',$this->CreateFormStart($id, 'doinstall', $returnid).
+				$this->CreateInputHidden($id,'modlist',base64_encode(serialize($deps))));
+			$this->smarty->assign('time_warning',$this->Lang('time_warning'));
+			$this->smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', $this->Lang('install_submit')));
+			$this->smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
+		
+		    echo $this->ProcessTemplate('installinfo.tpl');
+			return;
+			}
+
+		$params['modlist']=base64_encode(serialize($deps));
+		$this->_DoInstallLoop($id, $params, $returnid);
+		}
+		
+	
+	
+   function _DoInstallLoop($id, &$params, $returnid)
+		{
+		global $gCms;
+		$db = $gCms->GetDb();
+		
+		if (isset($params['cancel']))
+			{
+			return $this->DoAction('defaultadmin', $id, $params, $returnid);
+			}
+		
+		@set_time_limit(999);
+		$installs = array_reverse(unserialize(base64_decode($params['modlist'])));
+	    $url = $this->GetPreference('module_repository');
+	    if( $url == '' )
+			{
+			$this->_DisplayErrorPage( $id, $params, $returnid,
+					  $this->Lang('error_norepositoryurl'));
+			return;
+			}
+		
+		$nusoap =& $this->GetModuleInstance('nuSOAP');
+	    $nusoap->Load();
+	    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
+	    if( $err = $nu_soapclient->GetError() )
+	      {
+			$this->_DisplayErrorPage( $id, $params, $returnid,
+					  $this->Lang('soaperror',$err));
+			return;
+	      }
+		$messages = array();
+		$ok = true;
+		foreach($installs as $this_inst)
+			{
+			$thisRes = new stdClass();
+			$thisRes->success = false;
+			$thisRes->module_name = $this_inst['name'];
+			if ($ok)
+				{
+				if ($this_inst['status'] == 'a')
+					{
+					// activating
+					$query = "UPDATE ".cms_db_prefix()."modules SET active = ? WHERE module_name = ?";
+					$db->Execute($query, array(1,$this_inst['name']));
+					$thisRes->message = $this->Lang('action_activated',$this_inst['name']);
+					$thisRes->success = true;
+					}
+				else if ($this_inst['status'] == 'u')
+					{
+					// upgrading	
+					list($success, $msgs) = $this->_DoInstallOperation($this_inst, $nu_soapclient, true);
+					if (!$success)
+						{
+						$ok = false;
+						}
+					else
+						{
+						$thisRes->success = true;
+						}
+					$thisRes->message = $msgs;
+					}
+				else if ($this_inst['status'] == 'i')
+					{
+					// installing
+					list($success, $msgs) = $this->_DoInstallOperation($this_inst, $nu_soapclient, false);
+					if (!$success)
+						{
+						$ok=false;
+						}
+					else
+						{
+						$thisRes->success = true;
+						}
+					$thisRes->message = $msgs;
+					}
+				}
+			else
+				{
+				$thisRes->message = $this->Lang('error_skipping',$this_inst['name']);
+				}
+			if ($this_inst['status'] != 's')
+				{
+				$messages[] = $thisRes;
+				}
+			}
+		if ($ok)
+			{
+			$this->smarty->assign('title_installation_complete', $this->Lang('title_installation_complete'));	
+			}
+		else
+			{
+			$this->smarty->assign('title_installation_complete', $this->Lang('error_moduleinstallfailed'));
+			}
+	    
+	    $this->smarty->assign_by_ref('messages', $messages);
+		$this->smarty->assign('link_back',$this->CreateLink($id,'defaultadmin',$returnid, $this->Lang('back_to_module_manager')));	
+	    echo $this->ProcessTemplate('postinstall.tpl');
+		return;
+		
+		}
+
+	/* actual install or upgrade process; adapted from Calguy's code, extended madly */
+	function _DoInstallOperation(&$mod, &$nu_soapclient, $upgrade=false)
+	{
+		global $gCms;
+		$db = $gCms->GetDb();
+		
+		// get the xml file from soap
+	    $xml = '';
+	    $result = $this->_GetRepositoryXML($nu_soapclient,$mod['filename'],$mod['size'],$xml);
+	    if( $err = $nu_soapclient->GetError() )
+			{
+			return array(false,"<pre>".htmlspecialchars($nu_soapclient->response)."</pre><br/>");
+			}
+
+	    // get the md5sum from soap
+	    $svrmd5 = $nu_soapclient->call('ModuleRepository.soap_modulemd5sum',array('name' => $mod['filename']));
+	    if( $err = $nu_soapclient->GetError() )
+			{
+			return array(false,$this->Lang('soaperror',$err));
+			}
+
+		// calculate our own md5sum
+		// and compare
+		$clientmd5 = md5( $xml );
+
+		if( $clientmd5 != $svrmd5 )
+			{
+		 	return array(false,$this->Lang('error_checksum',array($svrmd5,$clientmd5)));
+			}
+
+		// woohoo, we're ready to rock and roll now
+		// just gotta expand the module
+		$modoperations = $gCms->GetModuleOperations();
+		if (!$modoperations->ExpandXMLPackage( $xml, 1 ) )
+			{
+			return array(false,$modoperations->GetLastError());
+			}
+
+		if ($upgrade)
+			{
+			// upgrade module
+			$query = "SELECT * FROM ".cms_db_prefix()."modules WHERE module_name = ?";
+		  	$dbresult = $db->Execute( $query, array( $mod['name'] ) );
+		  	$row = $dbresult->FetchRow();
+		  	$oldversion = $row['version'];
+			if ( !$modoperations->UpgradeModule( $mod['name'], $oldversion, $mod['version'] ) )
+				{
+				return array(false,$this->Lang('error_upgrade',$mod['name']).' '.$modoperations->GetLastError());	
+				}
+			return array(true,$this->Lang('action_upgraded',array($mod['name'])));
+			}
+		else
+			{
+			// and install it
+			$result = $modoperations->InstallModule( $mod['name'], true );	
+			}
+	 
+		if( $result[0] == true )
+			{
+			if( !isset( $gCms->modules[$mod['name']]['object'] ) )
+				{
+	    		// hopefully this will never happen
+				return array(false,$this->Lang('error_moduleinstallfailed'));
+				}
+			else
+	  			{
+				$cmsmodules = &$gCms->modules;
+				$msg = $cmsmodules[$mod['name']]['object']->InstallPostMessage();
+				return array(true,$msg);
+				}
+			}
+		else
+			{
+			return array(false,$this->Lang('error_moduleinstallfailed')."&nbsp;:".$result[1]);
+			}
+		}
+	
+   function _IsDependencyKnown(&$deps,$filename)
+   {
+		foreach ($deps as $dkey=>$td)
+			{
+			if ($td['filename'] == $filename)
+				{
+				return true;
+				}
+			}
+		return false;
+   }
+
+	function _DeDupeDependencies($deps)
+	{
+		// inconsistent behavior of array_splice in some PHP versions forces this clumsy approach
+		$dl = array_reverse($deps);
+		$known = array();
+		$deps = array();
+		foreach ($dl as $dkey=>$dval)
+			{
+			if (! isset($known[$dval['filename']]))
+				{
+				$deps[] = $dval;
+				$known[$dval['filename']] = true;
+				}
+			}
+		return array_reverse($deps);
+	}
+		
+   function _ModNameFromFile(&$allmods,$filename)
+	{
+		foreach ($allmods as $tm)
+			{
+			if ($tm['filename'] == $filename)
+				{
+				return $this->Lang('mod_name_ver',array($tm['name'],$tm['version']));
+				}
+			}
+		return $this->Lang('unknown');
+	}
+		
+   function _AddDependenciesToList($startspec, &$allmods, &$deplist)
+	{
+		list($res, $this_file_deps) = $this->_GetFileDependencies($startspec);
+		if (! $res)
+			{
+		 	 return array(false, $this_file_deps);				
+			}
+		if (is_array($this_file_deps))
+			{
+			foreach($this_file_deps as $this_dep)
+				{
+				$found = false;
+				foreach ($allmods[1] as $tm)
+					{
+					if ($tm['name'] == $this_dep['name'] && version_compare($tm['version'], $this_dep['version']) >= 0)
+						{
+						// found the module - add to list; we'll de-dupe later
+						$found = true;
+						$newDep = array('filename'=>$tm['filename'],'name'=>$tm['name'],
+										'version'=>$tm['version'],'by'=>$startspec,
+										'size'=>$tm['size']);
+						$deplist[] = $newDep;
+						$this->_AddDependenciesToList($tm['filename'], $allmods, $deplist);
+						}
+					}
+				if (! $found)
+					{
+				 	 return array(false, $this->Lang('error_unsatisfiable_dependency', array($this_dep['name'],$this_dep['version'], $this->_ModNameFromFile($allmods[1],$startspec) )));				
+					}
+				}
+			}
+		return array(true,'');
+	}
+
+   function _GetFileDependencies($filename)
+	{
+	    $url = $this->GetPreference('module_repository');
+	    if( $url == '' )
+	      {
+			$this->_DisplayErrorPage( $id, $params, $returnid,
+					  $this->Lang('error_norepositoryurl'));
+			return;
+	      }
+	    $nusoap =& $this->GetModuleInstance('nuSOAP');
+	    $nusoap->Load();
+	    $nu_soapclient = new nu_soapclient($url,false,false,false,false,false,90,90);
+	    if( $err = $nu_soapclient->GetError() )
+	      {
+			$this->_DisplayErrorPage( $id, $params, $returnid,
+					  'SOAP Error: '.$err);
+			return;
+	      }
+
+	    // get the dependencies from soap
+	    $depends = $nu_soapclient->call('ModuleRepository.soap_moduledepends',array('name' => $filename ));
+	    if( $err = $nu_soapclient->GetError() )
+	      {
+			$this->_DisplayErrorPage( $id, $params, $returnid,
+					  'SOAP Error: '.$err);
+			echo htmlspecialchars($nu_soapclient->response);
+			return;
+	      }
+	    if( $depends[0] == false )
+	      {
+			$this->_DisplayErrorPage( $id, $params, $returnid,
+					  $depends[1] );
+			return;
+	      }
+		
+	return ($depends);
+	}
+
+
   /*----------------------------------------------------------
    _GetInstalledModules
    build a hash of info about the installed modules.
    ---------------------------------------------------------*/
-  function _GetInstalledModules()
+  function _GetInstalledModules($include_inactive=false, $as_hash=false)
   {
     global $gCms;
+	if ($include_inactive)
+		{
+		// try to force a reload of modules; if we fail, just use the list of active modules that we have
+		$ml = $gCms->GetModuleLoader();
+		if ($ml)
+			{
+			$ml->LoadModules(true);
+			}
+		}
     $results = array();
     foreach( $gCms->modules as $key => $value )
       {
@@ -1095,10 +1547,25 @@ class ModuleManager extends CMSModule
 	$details['name'] = $modinstance->GetName();
 	$details['description'] = $modinstance->GetDescription();
 	$details['version'] = $modinstance->GetVersion();
+	if ($include_inactive)
+		{
+		$details['active'] = $value['active'];
+		}
+	else
+		{
+		$details['active'] = true;	
+		}
 	// todo, here, check to see if there's write permission
 	// for the httpd user to every one of the files
 	// in the module's directory.
-	$results[] = $details;
+	if ($as_hash)
+		{
+		$results[$details['name']] = $details;	
+		}
+	else
+		{
+		$results[] = $details;	
+		}
       }
     return array(true,$results);
   }
