@@ -1,15 +1,23 @@
 <?php
+$lang['info_detail_returnid'] = 'Cette pr&eacute;f&eacute;rence est utilis&eacute;e pour d&eacute;termin&eacute;e si une page (et donc un gabarit) sert pour l&#039;affichage des pages de d&eacute;tails. Les URLs individualis&eacute;es ne fonctionneront pas si ce param&egrave;tre n&#039;est pas d&eacute;fini pour une page valide. En outre, si cette pr&eacute;f&eacute;rence est activ&eacute;e, et aucun param&egrave;tre page de d&eacute;tail n&#039;est fourni sur la balise {news}, alors cette valeur sera utilis&eacute;e pour des liens pages de d&eacute;tails';
+$lang['title_detail_returnid'] = 'Page par d&eacute;faut &agrave; utiliser pour des vues de d&eacute;tail';
+$lang['title_submission_settings'] = 'Param&egrave;tres de soumission des articles (News)';
+$lang['title_fesubmit_settings'] = 'Param&egrave;tres de soumission via le Frontend';
+$lang['title_notification_settings'] = 'Param&egrave;tres des notifications';
+$lang['title_detail_settings'] = 'Param&eacute;tres d&#039;affichage des d&eacute;tails';
+$lang['error_invalidurl'] = 'URL incorrecte <em>(peut-&ecirc;tre d&eacute;j&agrave; utilis&eacute;e, ou il y a des caract&egrave;res non valides)</em>';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Les articles expir&eacute;s peuvent appara&icirc;tre dans les r&eacute;sultats de recherche&nbsp;';
-$lang['helpshowall'] = 'Si positionn&eacute; &agrave; 1 : voir tous les articles, quelle que soit la date de fin';
+$lang['helpshowall'] = 'Si positionn&eacute; &agrave; 1 : affiche tous les articles, quelle que soit la date de fin';
 $lang['error_invaliddates'] = 'Une ou plusieurs dates entr&eacute;es sont invalides';
 $lang['notify_n_draft_items_sub'] = '%d article(s)';
-$lang['notify_n_draft_items'] = 'Vous avez %s non publi&eacute;(s)';
+$lang['notify_n_draft_items'] = 'Vous avez %s article(s) non publi&eacute;(s)';
 $lang['unlimited'] = 'Sans limite';
 $lang['none'] = 'Aucun';
 $lang['anonymous'] = 'Anonyme';
 $lang['unknown'] = 'Inconnu';
 $lang['fesubmit_redirect'] = 'PageID ou alias o&ugrave; se fera la redirection apr&egrave;s qu&#039;un article ait &eacute;t&eacute; soumis via l&#039;action fesubmit&nbsp;';
-$lang['allow_summary_wysiwyg'] = 'Autoriser l&#039;utilisation de l&#039;&eacute;diteur WYSIWYG dans le champ sommaire&nbsp;';
+$lang['allow_summary_wysiwyg'] = 'Autoriser l&#039;utilisation de l&#039;&eacute;diteur WYSIWYG dans le sommaire&nbsp;';
 $lang['title_browsecat_template'] = 'Gabarit de cat&eacute;gories';
 $lang['title_browsecat_sysdefault'] = 'Gabarit de cat&eacute;gories par d&eacute;faut';
 $lang['browsecattemplate'] = 'Gabarit de cat&eacute;gories';
@@ -90,7 +98,7 @@ $lang['prevpage'] = '<';
 $lang['nextpage'] = '>';
 $lang['lastpage'] = '>>';
 $lang['prompt_of'] = 'sur';
-$lang['prompt_pagelimit'] = 'Nombre de pages&nbsp;';
+$lang['prompt_pagelimit'] = 'Nombre par page&nbsp;';
 $lang['prompt_sorting'] = 'Tri&eacute; par&nbsp;';
 $lang['title_filter'] = 'Filtres';
 $lang['published'] = 'Publi&eacute;';
@@ -146,9 +154,9 @@ $lang['startdatetoolate'] = 'la date de d&eacute;but est pass&eacute;e (apr&egra
 $lang['nocontentgiven'] = 'Aucun contenu entr&eacute;';
 $lang['noitemsfound'] = '<strong>Aucun</strong> objet trouv&eacute; pour cette cat&eacute;gorie: %s';
 $lang['nopostdategiven'] = 'Il manque la date &agrave; laquelle l&#039;article sera post&eacute;';
-$lang['note'] = '<em>Note :</em> Les dates doivent &ecirc;tre entr&eacute;es dans ce format &#039;yyyy-mm-dd hh:mm:ss&#039;.';
-$lang['notitlegiven'] = 'Aucun titre entr&eacute;';
-$lang['nonamegiven'] = 'Aucun nom donn&eacute;';
+$lang['note'] = '<em>Note :</em> les dates doivent &ecirc;tre entr&eacute;es dans ce format &#039;yyyy-mm-dd hh:mm:ss&#039;.';
+$lang['notitlegiven'] = 'Aucun titre n&#039;est entr&eacute;';
+$lang['nonamegiven'] = 'Aucun nom n&#039;a &eacute;t&eacute; donn&eacute;';
 $lang['numbertodisplay'] = 'Nombre &agrave; afficher (vide = toutes les entr&eacute;es)&nbsp;';
 $lang['print'] = 'Imprimer';
 $lang['postdate'] = 'Date &agrave; laquelle l&#039;article sera post&eacute;&nbsp;';
@@ -278,9 +286,9 @@ $lang['help'] = '<h3>Notes Importantes</h3>
 <li>Cliquer sur le bouton Envoyer</li>
 </ul>
 <p>Ces diff&eacute;rentes &eacute;tapes r&eacute;solvent le probl&egrave;me de ces nouveaux gabarits afin d&#039;&eacute;viter les diff&eacute;rentes erreurs de Smarty quand vous mettez &agrave; jour vers une version de CMS avec un module de News version 2.3 ou sup&eacute;rieure.</p>';
-$lang['qca'] = 'P0-1624099198-1262715852421';
-$lang['utmz'] = '156861353.1270972550.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utma'] = '156861353.1209407735.1270972550.1270972550.1271003718.2';
+$lang['qca'] = 'P0-1532147203-1273233257739';
+$lang['utma'] = '156861353.1552570550.1277739492.1284456886.1284478759.4';
+$lang['utmz'] = '156861353.1284138366.2.2.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
