@@ -1,4 +1,12 @@
 <?php
+$lang['info_detail_returnid'] = 'Den h&auml;r inst&auml;llningen anv&auml;nds f&ouml;r att best&auml;mma en sida (och d&auml;rf&ouml;r en mall) som ska anv&auml;ndas f&ouml;r att visa detaljsidor. Individualiserad nyhets-detalj webbadresser kommer inte att fungera om den h&auml;r parametern inte &auml;r satt till en giltig sida. Dessutom, om detta &auml;r inst&auml;llt, och ingen detaljside parameter anges p&aring; nyhets taggen, s&aring; kommer detta v&auml;rde att anv&auml;ndas f&ouml;r detaljl&auml;nkar.';
+$lang['title_detail_returnid'] = 'Standardsida f&ouml;r detalj visning';
+$lang['title_submission_settings'] = 'Inst&auml;llningar vid tillagd nyhet';
+$lang['title_fesubmit_settings'] = 'Inst&auml;llningar vid tillagd nyhet fr&aring;n framsidan';
+$lang['title_notification_settings'] = 'Notiferingsinst&auml;llningar';
+$lang['title_detail_settings'] = 'Inst&auml;llningar f&ouml;r detaljvisningar';
+$lang['error_invalidurl'] = 'Ogiltig webbadress <em> (kanske den redan anv&auml;nds, eller om det finns ogiltiga tecken) </ em>';
+$lang['url'] = 'Url';
 $lang['expired_searchable'] = 'Till&aring;t artiklar som passerat slutdatum att visas i s&ouml;kresultat';
 $lang['helpshowall'] = 'Visa alla artiklar, oavsett slutdatum';
 $lang['error_invaliddates'] = 'Ett eller flera av datumen som skrevs in &auml;r ogiltigt';
@@ -20,6 +28,8 @@ $lang['expiry_date_desc'] = 'Utg&aring;ngsdatum fallande';
 $lang['expiry_date_asc'] = 'Utg&aring;ngsdatum stigande';
 $lang['title_desc'] = 'Titel stigande';
 $lang['title_asc'] = 'Titel fallande';
+$lang['status_desc'] = 'Status Fallande';
+$lang['status_asc'] = 'Status Stigande';
 $lang['fesubmit_status'] = 'Statusen f&ouml;r nyhetsartiklar som skickas via framsidan/frontend';
 $lang['error_invalidfiletype'] = 'Kan inte ladda upp den h&auml;r filtypen';
 $lang['error_upload'] = 'Problem uppstod n&auml;r fil laddades upp';
@@ -271,8 +281,9 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.120607462.1233740298.1239218099.1239222156.7';
-$lang['utmz'] = '156861353.1239218099.6.5.utmccn=(referral)|utmcsr=umearugby.se|utmcct=/admin/moduleinterface.php|utmcmd=referral';
+$lang['utma'] = '156861353.622613290.1282068801.1286133816.1286141542.24';
+$lang['utmz'] = '156861353.1284652314.14.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1267218368-1282068801788';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1286141542';
 ?>
\ No newline at end of file
