@@ -1,5 +1,6 @@
 <?php
 $lang["friendlyname"]="TinyMCE WYSIWYG";
+$lang["admindescription"]="This module allows mainly content, but possibly also other kinds of data, to be edited using a WYSIWYG editor powered by the TinyMCE project.";
 $lang['uninstalled'] = 'Module Uninstalled.';
 $lang['installed'] = 'Module version %s installed.';
 $lang['stripbackgroundtags'] = 'Strip Background Tags From CSS';
@@ -63,6 +64,12 @@ $lang['editor_height_text']='Height of editor field';
 $lang['auto']='Auto';
 $lang["or"]="or";
 
+$lang["testarea_tab"]="Testing area";
+$lang["showtestingoutput"]="Show testing output";
+$lang["testareaeditor"]="Testing area editor";
+$lang["testareaoutput"]="Testing area output";
+$lang["testareaoutputsource"]="Testing area source";
+
 $lang["allowresizing"]="Allow inplace resizing of editor field";
 $lang["resizenone"]="Do not allow resizing";
 $lang["resizeboth"]="Allow resizing in both directions";
@@ -84,6 +91,13 @@ $lang["loadcmslinkerhelp"]="This generates the javascript-code needed to allow '
 $lang["cmslinkerstyletext"]="CMS-linker link-style";
 $lang["cmsselflinkstyle"]="{cms_selflink}-style";
 $lang["ahrefstyle"]="&lt;a href&gt;-style";
+$lang["cmslinkeraddstext"]="CMS-linker additions";
+$lang["cmslinkeraddshelp"]="This allows you to add stuff to either the &lt;a href&gt;-tag or {cms_selflink}, when generated by CMS-linker.";
+
+
+$lang["avoidlinkconversiontext"]="Avoid link conversion";
+$lang["avoidlinkconversionhelp"]="Turns TinyMCE's builtin link conversion logic off. Makes {smarty}-usage in urls possible.";
+
 $lang["relativeurlstext"]="Generate relative urls";
 $lang["forcecleanpastetext"]="Force clean on paste";
 $lang["forcecleanpastehelp"]="This should be enabled to remove strange formatting codes when pasting from Word etc.";
@@ -116,7 +130,7 @@ $lang['submit'] = 'Submit';
 $lang['update'] = 'Update';
 $lang["savesettings"]="Save settings";
 $lang['settings'] = 'Settings';
-$lang["settingssaved"]="Settings was saved";
+$lang["settingssaved"]="Settings were saved";
 $lang["saveadvanced"]="Save advanced settings";
 $lang["advancedsaved"]="Advanced settings saved";
 $lang["toolbarsaved"]="Toolbar was saved";
@@ -140,6 +154,7 @@ $lang['plugins_tab'] = 'Plugins';
 $lang['plugins_help'] = 'Choose the plugins you want to activate. Documentation can be found <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">here</a>';
 $lang['plugins_text'] = 'Plugins';
 $lang['saveplugins'] = 'Save plugins';
+$lang['pluginssaved']="Plugins saved";
 $lang['plugins_module'] = 'Module Plugins';
 $lang['plugins_common'] = 'Common Plugins';
 
@@ -166,6 +181,7 @@ $lang["filetoobig"]="Uploaded file is too big";
 $lang["containsillegalchars"]="Filename contains one or more illegal characters (',\",+,*,\\,/,&,$)";
 $lang["uploadfailed"]="Error moving uploaded file into place";
 $lang["fileuploaded"]="File successfully uploaded";
+$lang["notanimage"]="The uploaded file is not an image";
 
 $lang["filepickertitle"]="CMSMadeSimple File Selection";
 $lang["success"]="Success";
