@@ -1,5 +1,6 @@
 <?php
 $lang['friendlyname'] = 'TinyMCE WYSIWYG Editor';
+$lang['admindescription'] = 'Met deze module kunt u door middel van een WYSIWYG editor pagina inhoud, maar mogelijk ook andere vormen van data verwerken. Met dank aan het TinyMCE project.';
 $lang['uninstalled'] = 'Module gede&iuml;nstalleerd.';
 $lang['installed'] = 'Module versie %s ge&iuml;nstalleerd.';
 $lang['stripbackgroundtags'] = 'Verwijder &quot;background&quot; tags uit CSS';
@@ -47,20 +48,25 @@ $lang['showthumbnailfilestext'] = 'Toon de miniatuur-bestanden in de lijst met b
 $lang['filenameandthumbnails'] = 'Toon zowel bestandsnamen en miniaturen';
 $lang['skinstext'] = 'Skin ';
 $lang['skinvariationtext'] = 'Skin variant';
-$lang['advancedwarning'] = '<strong>Let op!<br/>Het wijzigen van deze instellingen kan het gevolg hebben dat TinyMCE stopt met functioneren of dat de door TinyMCE gegenereerde code niet meer correct is. Wijzig dit alleen als u weet wat u doet! Raadpleeg eerst de TinyMCE website voordat u hiermee gaat knutselen.</strong> ';
+$lang['advancedwarning'] = '<strong>Let op!<br/>Het wijzigen van deze instellingen kan gevolgen hebben voor het daadwerkelijk functioneren van de TinyMCE editor, of dat de door TinyMCE gegenereerde code niet meer correct is.<br />Wijzig dit alleen als u weet wat u doet!<br />Raadpleeg eerst de TinyMCE website voordat u hiermee gaat experimenteren.</strong> ';
 $lang['entityencoding_text'] = 'Coderen van entiteiten';
 $lang['rawencoding'] = 'Grove codering (snelst, werkt in de meeste gevallen)';
 $lang['namedencoding'] = 'Benoemde codering (zoals &nbsp;)';
 $lang['numericencoding'] = 'Numerieke codering (zoals &amp;#160;)';
 $lang['show_path_text'] = 'Het pad van het element onderaan in de editor tonen.';
 $lang['toolbar_tab'] = 'Werkbalk';
-$lang['toolbar_help'] = 'Deze opties moeten een kommagescheidenlijst van knoppen/control-namen bevatten die in de werkbalk worden opgenomen. De karakter | kan worden gebruikt in plaats van het woord &#039;seperator&#039;';
+$lang['toolbar_help'] = 'Deze opties moeten een komma gescheiden lijst van knoppen/control-namen bevatten die in de werkbalk worden opgenomen. Een karakter | kan worden gebruikt in plaats van het woord &#039;seperator&#039;';
 $lang['toolbar_text'] = 'Werkbalk';
 $lang['toolbarhelptext'] = 'Klik hier om de werkbalk-instructies op TinyMCE-wiki te bekijken.';
 $lang['editor_width_text'] = 'Breedte van het editor veld';
 $lang['editor_height_text'] = 'Hoogte van het editor veld';
 $lang['auto'] = 'Automatisch';
 $lang['or'] = 'of';
+$lang['testarea_tab'] = 'Test Editor';
+$lang['showtestingoutput'] = 'Toon Test Resultaten';
+$lang['testareaeditor'] = 'Editor Testruimte';
+$lang['testareaoutput'] = 'Gegenereerd resultaat';
+$lang['testareaoutputsource'] = 'Gegenereerde broncode';
 $lang['allowresizing'] = 'Sta het verschalen in de editor toe';
 $lang['resizenone'] = 'Verschalen niet toestaan';
 $lang['resizeboth'] = 'Sta het verschalen in beide richtingen toe';
@@ -82,6 +88,10 @@ $lang['loadcmslinkerhelp'] = 'Dit genereert de javascript-code die nodig is om d
 $lang['cmslinkerstyletext'] = 'CMS-linker link-style ';
 $lang['cmsselflinkstyle'] = 'cms_selflink-stijl';
 $lang['ahrefstyle'] = 'a href-stijl';
+$lang['cmslinkeraddstext'] = 'CMS-linker toevoegingen';
+$lang['cmslinkeraddshelp'] = 'Hiermee kunt u code toevoegen aan de a-href, of cms_selflink-tag, wanneer de is gegenereerd door de CMS-linker.';
+$lang['avoidlinkconversiontext'] = 'Voorkom link aanpassingen';
+$lang['avoidlinkconversionhelp'] = 'Schakelt TinyMCE&#039;s ingebouwde link aanpassing logica uit. Dit maakt het gebruik van {smarty}-tags in de url mogelijk.';
 $lang['relativeurlstext'] = 'Genereer relatieve urls';
 $lang['forcecleanpastetext'] = 'Forceer opschonen na plakken';
 $lang['forcecleanpastehelp'] = 'Deze moet geactiveerd worden om vreemde opmaak te verwijderen bij plakken vanuit Word etc...';
@@ -90,8 +100,8 @@ $lang['bodycss_help'] = 'Wordt toegevoegd aan de CSS Body Div. Tip: Om voor de a
 $lang['includeonlyscreencss_text'] = 'Gebruik alleen &#039;screen&#039; CSS';
 $lang['includeonlyscreencss_help'] = 'Selecteren van deze optie zorgt ervoor dat enkel &#039;screen&#039;-mediatype kan worden geselecteerd in TinyMCE handles.';
 $lang['usestaticconfigtext'] = 'Gebruik statische configuratiebestand';
-$lang['usestaticconfighelp'] = 'Dit kan helpen om TinyMCE te laten werken op systemen waar de Host, statistieken etc. in alle output plaats, waarmee dynamische javascripts niet correct zijn.';
-$lang['usestaticconfigwarning'] = 'Waarschuwing! Je hebt het statische configuratiebestand ingeschakeld, maar je /tmp/ map is niet schrijfbaar. Dit zorgt ervoor dat het statische configuratiebestand niet kan worden weggeschreven, waardoor TinyMCE niet zal werken.';
+$lang['usestaticconfighelp'] = 'Dit kan helpen om TinyMCE te laten werken op systemen waar de host ervoor zorgt dat er elementen zoals statistieken en dergelijke toegevoegd worden aan alle output. Dit zorgt ervoor dat dynamisch gecre&euml;erd javascript corrupt raakt.';
+$lang['usestaticconfigwarning'] = 'Waarschuwing! U heeft het statische configuratiebestand ingeschakeld, maar uw /tmp/ map is niet beschrijfbaar. Dit zorgt ervoor dat het statische configuratiebestand niet kan worden weggeschreven, waardoor TinyMCE niet zal werken.';
 $lang['ignoremodifyfilestext'] = 'Negeer de &#039;Modify Files&#039; rechten voor de FilePicker';
 $lang['ignoremodifyfileshelp'] = 'Waarschuwing! Hiermee staat u bepaalde bestandsbeheer rechten toe, ook als voor deze gebruikersgroep het &#039;Modify Files&#039; recht niet is ingesteld. Deze optie kan goed worden gebruikt in combinatie met de optie &quot;Beperk gebruikerstoegang tot de servermappen&quot;';
 $lang['showtogglebutton_text'] = 'Aanvinkvak tonen om WYSIWYG aan of uit te zetten';
@@ -126,15 +136,16 @@ $lang['cmsmslinker'] = 'Voeg een interne link toe';
 $lang['backend_toolbars'] = 'Backend profiel instellingen';
 $lang['frontend_toolbars'] = 'Frontend profiel instellingen';
 $lang['plugins_tab'] = 'Plugins ';
-$lang['plugins_help'] = 'Kies de plugins die je wilt activeren. Documentatie kan <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">hier</a> worden gevonden.';
+$lang['plugins_help'] = 'Kies de plugins die u wilt activeren. Documentatie kan <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">hier</a> worden gevonden.';
 $lang['plugins_text'] = 'Plugins ';
 $lang['saveplugins'] = 'Plugins opslaan';
+$lang['pluginssaved'] = 'Plugins opgeslagen';
 $lang['plugins_module'] = 'Module plugins';
 $lang['plugins_common'] = 'Algemene plugins';
 $lang['module'] = 'Module ';
 $lang['description'] = 'Omschrijving';
 $lang['plugin'] = 'Plugin ';
-$lang['youareintext'] = 'Je bent in';
+$lang['youareintext'] = 'U bent in';
 $lang['loadstylesheettext'] = 'Stylesheet laden voor de &#039;content&#039; (aanbevolen)';
 $lang['extrastylestext'] = 'Toevoegingen aan stylesheets';
 $lang['extrastyleshelp'] = 'CSS-logica die hier wordt toegevoegd, zal aan de stylesheet worden toegevoegd die door TinyMCE wordt toegepast, na het openen van de CMSms stylesheet';
@@ -146,11 +157,12 @@ $lang['nodirname'] = 'Geen mapnaam opgegeven';
 $lang['direxists'] = 'Map bestaat reeds';
 $lang['newdircreated'] = 'Nieuwe map aangemaakt';
 $lang['newdirfailed'] = 'Fout opgetreden bij aanmaken van een map';
-$lang['nofile'] = 'Er is geen bestand opgeladen';
-$lang['filetoobig'] = 'Opgeladen bestand is te groot';
+$lang['nofile'] = 'Er is geen bestand ge&uuml;pload';
+$lang['filetoobig'] = 'Ge&uuml;pload bestand is te groot';
 $lang['containsillegalchars'] = 'De bestandsnaam bevat &eacute;&eacute;n of meer niet-toegestane karakters (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Fout bij verplaatsen bestand';
 $lang['fileuploaded'] = 'Bestand opgeladen';
+$lang['notanimage'] = 'Het ge&uuml;ploade bestand is geen afbeelding';
 $lang['filepickertitle'] = 'CMS Made Simple Bestandsselectie';
 $lang['success'] = 'Gelukt';
 $lang['fileoperations'] = 'Bestandbewerkingen';
@@ -158,7 +170,7 @@ $lang['thousanddelimiter'] = ', ';
 $lang['size'] = 'Afmetingen';
 $lang['dimensions'] = 'BxH';
 $lang['advanced_tab'] = 'Geavanceerd';
-$lang['help'] = '	<h3>What does this do? </h3>
+$lang['help'] = '	<h3>What does this do?</h3>
 	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
 	<h3>How do I use it?</h3>
 	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
@@ -169,19 +181,22 @@ $lang['help'] = '	<h3>What does this do? </h3>
 	things you can try before contacting me for further support.
 	<br/>
 	<ul>
-	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
-	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
-	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
-	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
+	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>	
+	<li>2. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changed from 2.3.x to 2.4.x series of the module.
+	<li>3. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based), Note that this requires your /tmp/-dir to be writable by the webserver
 	</ul>
-	<br/>
-		
+	<br />
+  <h3>Plugin development</h3>
+  As of version 2.7.0 the TinyMCE-module has the ability to allow other modules to register extensions for it. Could be a custom icon allowing you to insert
+  content from some module, like Gallery etc. How to do this is pretty tech stuff, but if you are a module developer and interested in checking it out
+  please look in the TinyMCE/docs-dir for further instructions.
+
 
 		
 ';
-$lang['utma'] = '156861353.1269027775.1259416186.1271433445.1271435136.649';
-$lang['utmz'] = '156861353.1271433445.648.115.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,42599.msg205055.html';
-$lang['qca'] = 'P0-431297011-1259416186230';
-$lang['utmb'] = '156861353.5.10.1271435136';
+$lang['utma'] = '156861353.1335698708.1284586217.1288551918.1288619010.261';
+$lang['utmz'] = '156861353.1288551918.260.31.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = 'P0-1551306179-1284586216711';
+$lang['utmb'] = '156861353.1.10.1288619010';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
